#include <QDir>
#include <QFile>
#include <QUrl>
#include <QRegExp>
#include <QTextStream>
#include <QDebug>

#include "document.h"

Document::Document(PlaylistItem *item, QWidget *parent)
    : QWebView(parent)
{
    m_time = item->time();
    m_uri = item->uri();

    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onTimeout()));
}

void Document::run()
{
    QString basePath = QString("file://") + QDir::homePath() + QString("/.linutop-kiosk/data/");

    QFile f(m_uri.mid(7));
    if(!f.open(QIODevice::ReadOnly))
       emit(end());
    QTextStream in(&f);
    QString html = in.readAll();
    f.close();

    setHtml(parseTemplate(html, basePath), QUrl(basePath));
    m_timer.start(1000 * m_time);
}

void Document::onTimeout()
{
    m_timer.stop();
    emit(end());
}

void Document::stop()
{
    m_timer.stop();
}

QString Document::parseTemplate(QString &html, QString &basePath)
{
    QRegExp limageRx("<limage([^>]*)>([^<]+)</limage>");
    int pos;

    while ((pos = limageRx.indexIn(html)) != -1) {
        QString encoded = basePath + limageRx.cap(2).toUtf8().toBase64().replace("/", "-");
        QString data = limageRx.cap(1);
        QString n = QString("<img src=\"%1\" \"%2\"/>").arg(encoded).arg(data);
        html.replace(pos, limageRx.matchedLength(), n);
    }

    qDebug() << html;

    return html;
}
