#include "pdf.h"

PDF::PDF(PlaylistItem *item, QWidget *parent)
    : QLabel(parent)
    , m_document(0)
{
    m_time = item->time();
    m_uri = item->uri().mid(7);
    m_document = Poppler::Document::load(m_uri);
    if (!m_document)
        emit(end());
    m_pageNb = -1;

    connect(&m_timer, SIGNAL(timeout()), this, SLOT(nextPage()));
}

void PDF::setBlackBackground()
{
    QPalette p;
    p.setColor(QPalette::Background, Qt::black);
    QLabel::setAutoFillBackground(true);
    QLabel::setPalette(p);
}

void PDF::nextPage()
{
    m_pageNb++;
    Poppler::Page *page = m_document->page(m_pageNb);
    m_timer.stop();
    if (! page)
    {
        emit(end());
        return;
    }

    QImage image = page->renderToImage(400,400);
    m_pixmap = QPixmap::fromImage(image);
    QRect g = qobject_cast<QWidget *>(QLabel::parent())->geometry();
    QPixmap pixmap;
    int p_w = g.width();
    int p_h = g.height();
    int s_w = m_pixmap.width();
    int s_h = m_pixmap.height();

    if ((s_w <= p_w) && (s_h <= p_h))
        pixmap = m_pixmap;
    else
        if (((float) s_w / p_w) > ((float) s_h / p_h))
            pixmap = m_pixmap.scaledToWidth(p_w, Qt::SmoothTransformation);
        else
            pixmap = m_pixmap.scaledToHeight(p_h, Qt::SmoothTransformation);

    setPixmap(pixmap);
    setAlignment(Qt::AlignCenter);
    setBlackBackground();

    m_timer.start(1000 * m_time);

    delete page;
}

void PDF::run()
{
    nextPage();
}

void PDF::stop()
{
    m_timer.stop();
}
