#ifndef WEBPAGE_H
#define WEBPAGE_H

#include <QTimer>
#include <QWebView>
#include <QNetworkCookieJar>
#include <QUrl>
#include <QEvent>
#include <QSslError>

#include "runnable.h"
#include "playlistitem.h"

class SqliteCookieJar : public QNetworkCookieJar
{
    Q_OBJECT

public:
    SqliteCookieJar(QObject *parent = 0);

private:
    QList<QNetworkCookie> m_cookies;
};

class Webpage : public QWebView, public Runnable
{
    Q_OBJECT

public:
    Webpage(PlaylistItem *item, QWidget *parent);
    void run();
    void stop();
    bool isLoaded(){return loaded;}

protected:
    bool eventFilter(QObject *obj, QEvent *event);

private:
    QUrl m_uri;
    SqliteCookieJar *m_jar;
    bool loaded;

private slots:
    void onTimeout();
    void onLoadFinished(bool ok);
    void sslErrorHandler(QNetworkReply *, const QList<QSslError> &);

signals:
    void end();
};

class PostSession : public Webpage
{
    Q_OBJECT
};

#endif
